"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const disposable_1 = require("@phosphor/disposable");
const apputils_1 = require("@jupyterlab/apputils");
/**
 * The plugin registration information.
 */
const plugin = {
    activate,
    id: 'jupyter-lti:buttonPlugin',
    autoStart: true
};
let getUrl = (assignment_id) => {
    let proto = window.location.protocol;
    let parts = window.location.pathname.split('/');
    let version = parts[1];
    let serverName = parts[6];
    let projectName = parts[4];
    let accountName = parts[2];
    return `${proto}//${window.location.host}/${version}/${accountName}/projects/${projectName}/servers/${serverName}/lti/assignment/${assignment_id}/`;
};
let sendCallback = (assignment_id, context) => () => {
    let url = getUrl(assignment_id);
    let buttons = [apputils_1.Dialog.okButton()];
    let errorDialog = {
        title: 'Error',
        body: 'There was an error while sending submission',
        buttons: buttons
    };
    context.save();
    fetch(url, {
        method: 'POST',
        headers: { 'Content-Type': 'application/json;charset=utf-8' },
        referrerPolicy: 'no-referrer'
    })
        .then(res => {
        if (!res.ok) {
            console.log(res);
            apputils_1.showDialog(errorDialog);
        }
        else {
            apputils_1.showDialog({
                title: 'Success',
                body: 'Your assignment was sent to Canvas',
                buttons: buttons
            });
        }
    })
        .catch(error => {
        apputils_1.showDialog(errorDialog);
        console.error(error);
    });
};
let resetCallback = (assignment_id, context) => () => {
    let sendUrl = getUrl(assignment_id);
    let url = `${sendUrl}reset/`;
    let buttons = [apputils_1.Dialog.okButton()];
    let errorDialog = {
        title: 'Error',
        body: 'There was an error while reseting assignment file',
        buttons: buttons
    };
    context.save();
    fetch(url, {
        method: 'POST',
        headers: { 'Content-Type': 'application/json;charset=utf-8' },
        referrerPolicy: 'no-referrer'
    })
        .then(res => {
        if (!res.ok) {
            console.log(res);
            apputils_1.showDialog(errorDialog);
        }
        else {
            apputils_1.showDialog({
                title: 'Success',
                body: 'Your assignment file was reset',
                buttons: buttons
            });
        }
    })
        .catch(error => {
        apputils_1.showDialog(errorDialog);
        console.error(error);
    });
};
/**
 * A notebook widget extension that adds a button to the toolbar.
 */
class ButtonExtension {
    constructor(assignment_id) {
        this.assignment_id = assignment_id;
    }
    /**
     * Create a new extension object.
     */
    createNew(panel, context) {
        let self = this;
        let sendButton = new apputils_1.ToolbarButton({
            className: 'mySendButton',
            iconClassName: 'fa fa-share-square',
            onClick: sendCallback(self.assignment_id, context),
            tooltip: 'Submit to Canvas'
        });
        let resetButton = new apputils_1.ToolbarButton({
            className: 'myResetButton',
            iconClassName: 'fa fa-undo',
            onClick: resetCallback(self.assignment_id, context),
            tooltip: 'Reset assignment file'
        });
        panel.toolbar.insertItem(0, 'send', sendButton);
        panel.toolbar.insertItem(0, 'reset', resetButton);
        return new disposable_1.DisposableDelegate(() => {
            sendButton.dispose();
            resetButton.dispose();
        });
    }
}
exports.ButtonExtension = ButtonExtension;
/**
 * Activate the extension.
 */
function activate(app) {
    let query = new URLSearchParams(window.location.search);
    let assignment_id = query.get('assignment_id');
    if (!!assignment_id) {
        app.docRegistry.addWidgetExtension('Notebook', new ButtonExtension(query.get('assignment_id')));
    }
}
/**
 * Export the plugin as default.
 */
exports.default = plugin;
